Struct ReadWithContext

pub struct ReadWithContext<'p> { /* private fields */ }
Automatically count lines and report them and the path in error messages

Implementations

Source

impl<'p> ReadWithContext<'p>

pub fn open_path(path: &'p Path) -> Result<ReadWithContext<'p>>

pub fn easy_read_line(&mut self, line: &mut String) -> Result<bool>

“Clean” read_line function: returns true if it did read a line, false on EOF. Does overwrite line, not append to it. Removes trailing ‘\n’ if present.

pub fn err_with_context<T>(&self, err: Error) -> Result<T, Error>

Report an error in the context of this file and position

pub fn context<T>(&self, res: Result<T, Error>) -> Result<T, Error>

A Result in the context of this file and position