pub fn open_file(path: &Path) -> Result<BufReader<File>>
Easy buffered file opening with context on open errors. But see ReadWithContext instead for keeping context across subsequent calls, too.
ReadWithContext